iamai.adapter.dingtalk.dingtalk.exceptions module
=================================================

.. automodule:: iamai.adapter.dingtalk.dingtalk.exceptions
   :members:
   :undoc-members:
   :show-inheritance:
